@@ -247,14 +247,13 @@ Install Calibre, or edit %s to set proper path to it.""" % (
 
 
 def save_isbn(item, isbn):
-    print("Saving isbn %s to book %s" % (isbn, item))
+    print(u"Saving isbn {0} to book {1} ({2})".format(isbn, item.id, item.title))
     opf = subprocess.Popen(
         [CONFIG.calibredb, "show_metadata", item.id, "--as-opf"],
         stdout=subprocess.PIPE).communicate()[0]
     opf = opf.replace(
         "</metadata>",
-        """<dc:identifier opf:scheme="ISBN">%s</dc:identifier></metadata>""" \
-            % isbn)
+        """<dc:identifier opf:scheme="ISBN">{0}</dc:identifier></metadata>""".format(isbn))
     opf_file = NamedTemporaryFile(suffix=".opf", delete=False)
     opf_file.write(opf)
     opf_file.close()
