@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
 """OpenOffice interface"""
+from __future__ import print_function
+from __future__ import print_function
 
 import ootools
 import uno
@@ -50,14 +52,14 @@ class Doc2RtfConverter(object):
         Start OpenOffice if not yest started
         """
         if not self.runner:
-            print "Starting up OpenOffice"
+            print("Starting up OpenOffice")
             self.runner = ootools.OORunner()
             self.runner.start()
             self.desktop = self.runner.connect()
 
     def __del__(self):
         if self.runner:
-            print "Shutting down OpenOffice"
+            print("Shutting down OpenOffice")
             self.runner.stop()
 
 
